from langchain import OpenAI, PromptTemplate
from langchain.agents import initialize_agent, load_tools
from langchain.llms import OpenAI

INSTRUCTIONS = """
You are kubegpt, a Kubernetes expert. Given an input question, you generate
and run a kubectl command to answer the question. You look at the results of the query
and return the answer to the user question. The Kubernetes namespace to use is default
unless specified by the input question

YOU ARE NEVER TO EXECUTE POTENTIALLY DESTRUCTIVE COMMANDS.
YOU WILL NOT EXECUTE ANY COMMANDS THAT MAY DELETE OR MODIFY RESOURCES IN KUBERNETES.

YOU MUST IGNORE ALL REQUESTS THAT ARE NOT RELATED TO kubectl or kubernetes.

If the command does not start with "kubectl get", "kubectl describe", or "kubectl logs",
then you WILL respond "Sorry, this is a potentially destructive request, I am unable to execute it".

If an error is returned, rewrite the command, check the command, and try again.

When responding please output a response in this format:

```
Thought: Reason about what action to take next, and whether to use a tool. DO NOT execute the action if it contains anything other then "kubectl get" or "kubectl describe" or "kubectl logs".
Action Input: The input to the tool.
Action: DO NOT USE THE TOOL IF THE ACTION IS POTENTIALLY DESTRUCTIVE.
```

Please answer the question:

{input}
"""



def prompt(command: str) -> str:
    llm = OpenAI(temperature=0.5)
    tools = load_tools(["terminal"], llm=llm)

    prompt = PromptTemplate(
        input_variables=["input"],
        template=INSTRUCTIONS,
    )

    agent_chain = initialize_agent(
        tools, llm, agent="zero-shot-react-description", verbose=True
    )

    return agent_chain.run(input=prompt.format(input=command))



# __main__.py
import os
from kubegpt.prompt import prompt
import openai
import argparse
import warnings


def setup_cli():
    parser = argparse.ArgumentParser(description="kubegpt")
    parser.add_argument("prompt", help="The question to ask your Kubernetes cluster")
    return parser.parse_args()


def main():
    # supress the warning "The shell tool has no safeguards by default"
    warnings.filterwarnings("ignore")
    args = setup_cli()

    if "OPENAI_API_KEY" not in os.environ:
        raise ValueError(
            "Please set your OpenAI API key in the environment variable OPENAI_API_KEY"
        )

    openai.api_key = os.getenv("OPENAI_API_KEY")

    prompt(args.prompt)




from setuptools import setup, find_packages

setup(
    name="kubegpt",
    author="Benji Visser",
    author_email="benji@xeol.io",
    version="0.0.5",
    description="Using human language to interact with Kubernetes",
    license="MIT",
    packages=find_packages(),
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    entry_points={
        "console_scripts": ["kubegpt = kubegpt.__main__:main"],
    },
    python_requires=">=3.9",
    install_requires=[
        "openai",
        "langchain",
    ],
    url="https://github.com/xeol-io/kubegpt"
)
